# Clean the Assets Cache

After running several demos or simulations, the procedurally generated assets (such as textures and meshes) can accumulate in the cache. To free up disk space, you can clean this cache:

```bash
.docker/run.bash scripts/utils/clean_procgen_cache.py
```
